django_analyses.models.input package — django_analyses 0.0.3 documentation

# django_analyses.models.input package

## Subpackages

- django_analyses.models.input.definitions package
  - Submodules
  - django_analyses.models.input.definitions.boolean_input_definition module
  - django_analyses.models.input.definitions.directory_input_definition module
  - django_analyses.models.input.definitions.file_input_definition module
  - django_analyses.models.input.definitions.float_input_definition module
  - django_analyses.models.input.definitions.input_definition module
  - django_analyses.models.input.definitions.input_definitions module
  - django_analyses.models.input.definitions.integer_input_definition module
  - django_analyses.models.input.definitions.list_input_definition module
  - django_analyses.models.input.definitions.messages module
  - django_analyses.models.input.definitions.number_input_definition module
  - django_analyses.models.input.definitions.string_input_definition module
  - Module contents
- django_analyses.models.input.types package
  - Submodules
  - django_analyses.models.input.types.boolean_input module
  - django_analyses.models.input.types.directory_input module
  - django_analyses.models.input.types.file_input module
  - django_analyses.models.input.types.float_input module
  - django_analyses.models.input.types.input_types module
  - django_analyses.models.input.types.integer_input module
  - django_analyses.models.input.types.list_input module
  - django_analyses.models.input.types.number_input module
  - django_analyses.models.input.types.string_input module
  - Module contents

## Submodules

## django_analyses.models.input.input module

class `django_analyses.models.input.input.` `Input`(id, run)

  Bases: `django.db.models.base.Model`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  property `argument_value`
  `booleaninput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `definition` = None
  `directoryinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `fileinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `get_argument_value`()
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `key`
  `listinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `numberinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `objects` = <model_utils.managers.InheritanceManager object>
  `pre_save`() → None
  `raise_required_error`()
  `run`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `run_id`
  `save`(*args, **kwargs)

    Save the current instance. Override this in a subclass if you want to control the saving process.

    The ‘force_insert’ and ‘force_update’ parameters can be used to insist that the “save” must be an SQL insert or update (or equivalent for non-SQL backends), respectively. Normally, they should not be set.

  `stringinput`

    Accessor to the related object on the reverse side of a one-to-one relation.

    In the example:

        class Restaurant(Model):
            place = OneToOneField(Place, related_name='restaurant')

    `Place.restaurant` is a `ReverseOneToOneDescriptor` instance.

  `validate`() → None
  `value` = None

## django_analyses.models.input.input_specification module

class `django_analyses.models.input.input_specification.` `InputSpecification`(id, created, modified, analysis)

  Bases: `django_extensions.db.models.TimeStampedModel`

  exception `DoesNotExist`

    Bases: `django.core.exceptions.ObjectDoesNotExist`

  exception `MultipleObjectsReturned`

    Bases: `django.core.exceptions.MultipleObjectsReturned`

  `analysis`

    Accessor to the related object on the forward side of a many-to-one or one-to-one (via ForwardOneToOneDescriptor subclass) relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Child.parent` is a `ForwardManyToOneDescriptor` instance.

  `analysis_id`
  `analysis_version_set`

    Accessor to the related objects manager on the reverse side of a many-to-one relation.

    In the example:

        class Child(Model):
            parent = ForeignKey(Parent, related_name='children')

    `Parent.children` is a `ReverseManyToOneDescriptor` instance.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  `base_input_definitions`

    Accessor to the related objects manager on the forward and reverse sides of a many-to-many relation.

    In the example:

        class Pizza(Model):
            toppings = ManyToManyField(Topping, related_name='pizzas')

    `Pizza.toppings` and `Topping.pizzas` are `ManyToManyDescriptor` instances.

    Most of the implementation is delegated to a dynamically defined manager class built by `create_forward_many_to_many_manager()` defined below.

  property `default_configuration`
  `get_default_input_configurations`() → dict
  `get_next_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=True, **kwargs)
  `get_next_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=True, **kwargs)
  `get_previous_by_created`(*, field=<django_extensions.db.fields.CreationDateTimeField: created>, is_next=False, **kwargs)
  `get_previous_by_modified`(*, field=<django_extensions.db.fields.ModificationDateTimeField: modified>, is_next=False, **kwargs)
  `id`

    A wrapper for a deferred-loading field. When the value is read from this object the first time, the query is executed.

  property `input_definitions`
  `objects` = <django_analyses.models.managers.input_specification.InputSpecificationManager object>
  `validate_keys`(**kwargs) → None
  `validate_kwargs`(**kwargs) → None
  `validate_required`(**kwargs) → None

## django_analyses.models.input.utils module

class `django_analyses.models.input.utils.` `ListElementTypes`

  Bases: `django_analyses.utils.choice_enum.ChoiceEnum`

  An enumeration.

  `BLN` = 'Boolean'
  `FIL` = 'File'
  `FLT` = 'Float'
  `INT` = 'Integer'
  `STR` = 'String'

## Module contents